pitchtools.calculate_melodic_diatonic_interval_class
====================================================

.. autofunction:: abjad.tools.pitchtools.calculate_melodic_diatonic_interval_class.calculate_melodic_diatonic_interval_class
   :noindex:
